@@ -11,8 +11,6 @@ The following classes are defined:
 For adapting to other Directories like eDirectory the Generic* classes can be easily subclassed.
 See ADSLdapDict for example.
 
-$Id: ldapdict.py 1834 2008-03-03 13:27:44Z tongp01 $
-$URL: http://10.75.97.97/lnx/iena/aut/trunk/mpauth/mpshared/ldapdict.py $
 '''
 
 
@@ -23,6 +21,7 @@ import ldap.schema
 import ldap.modlist
 import ldif
 from UserDict import DictMixin
+from datetime import datetime
 # from UserList import UserList
 from pprint import pprint as pp
 from types import StringType, UnicodeType #, ListType, NoneType
@@ -164,6 +163,7 @@ class GenericLdapDict(DictMixin, object):
 
             ol.getparents()
             cache.dnidx[dnkey].append(ol.parents[0])
+            cache.dnidx[dnkey].append(datetime.utcnow())
 
         return ol
 
@@ -338,7 +338,7 @@ class GenericLdapDict(DictMixin, object):
             keys = self.data.keys()
         
         # hack around openldap not having RootDSE in schema 
-        if 'OpenLDAProotDSE' in classlist:
+        if classlist is not None and 'OpenLDAProotDSE' in classlist:
             keys = self.data.keys()
 
         # if not hasattr(self,'_keys'):
